pub(crate) fn remove_bytecode_dependencies(
gcx: Gcx<'_>,
deps: &PreprocessorDependencies,
data: &BTreeMap<ContractId, ContractData>,
) -> UpdatesExpand description
Goes over all test/script files and replaces bytecode dependencies with cheatcode invocations.
Try deployments remain native to preserve their constructor failure boundaries.